################################################
#           MSc Course on Econometrics         #
#             Loukia Meligkotsidou             #
################################################

# bult-in R routines for linear regression Y=BX+E

# Y: nx1 vector of observations on the dependent variable
# X: nxk matrix of observations on k covariates

# Load data
Y <- as.matrix(read.table("C:/Loukia/R_labs_Econometrics/Lab1/Y.txt"))
X <- as.matrix(read.table("C:/Loukia/R_labs_Econometrics/Lab1/X.txt"))
cor(X)

n <- length(Y)

# Create scatter plots of the data
par(mfrow=c(2,2))
plot(X[,1], Y,xlab = "X1", ylab = "Y")
plot(X[,2], Y,xlab = "X2", ylab = "Y")
plot(X[,3], Y,xlab = "X3", ylab = "Y")
plot(X[,4], Y,xlab = "X4", ylab = "Y")

# Linear regression using lm function
lm_model <- lm(Y ~ X) 
summary(lm_model)  # Print summary of linear regression results

# Get regression coefficients and other statistics
coefficients(lm_model)  # Coefficients
confint(lm_model)  # 95% confidence intervals
residuals(lm_model)  # Residuals
vcov(lm_model)  # Covariance matrix of coefficients
fitted(lm_model)  # Fitted values
deviance(lm_model)  # Residual sum of squares
summary(lm_model)$r.squared  # R-squared
summary(lm_model)$adj.r.squared  # Adjusted R-squared
summary(lm_model)$fstatistic  # F-statistic
summary(lm_model)$coefficients[, "t value"]  # t-statistics
summary(lm_model)$coefficients[, "Pr(>|t|)"]  # p-values

# Create a scatter plot of fitted values vs. residuals
plot(fitted(lm_model), residuals(lm_model),xlab = "Fitted Values", ylab = "Residuals")

# Stepwise regression (based on AIC)
step_model <- step(lm_model, direction = "forward")
summary(step_model)  # Print summary of stepwise regression results
step_model$anova

# Get stepwise regression coefficients and other statistics
#coefficients(step_model)  # Coefficients
#confint(step_model)  # 95% confidence intervals
#step_model$residuals  # Residuals
#vcov(step_model)  # Covariance matrix of coefficients
#fitted(step_model)  # Fitted values
#step_model$deviance  # Residual sum of squares
#step_model$adj.r.squared  # Adjusted R-squared
#step_model$fstatistic  # F-statistic