################################################
#           MSc Course on Econometrics         #
#             Loukia Meligkotsidou             #
################################################

# linear regression using R programming

# Y: nx1 vector of observations on the dependent variable
# X: nxk matrix of observations on k covariates


# Load data
Y <- as.matrix(read.table("C:/Loukia/R_labs_Econometrics/Lab1/Y.txt"))
X <- as.matrix(read.table("C:/Loukia/R_labs_Econometrics/Lab1/X.txt"))

dimX <- dim(X)
n=dimX[1]
k=dimX[2]
X <- cbind(1, X)  # Add a column of ones for the intercept term

# LS estimates
XX <- t(X) %*% X
XXinv <- solve(XX)
XY <- t(X) %*% Y
bhat <- XXinv %*% XY
bhat

# Unbiased estimator of error variance
ehat <- Y - X %*% bhat
sigmahat <- sum(ehat^2) / (n - k - 1)
sigmahat

# Covariance matrix of bhat
covbhat <- sigmahat * XXinv

# Standard errors of regression coefficients
se <- sqrt(diag(covbhat))
se

# 95% confidence intervals
t_critical <- qt(0.975, n - k - 1)
CIs <- cbind(bhat - se * t_critical, bhat + se * t_critical)
CIs

# F-test
R <- cbind(0, diag(k))
SSR <- t(R %*% bhat) %*% solve(R %*% XXinv %*% t(R)) %*% (R %*% bhat)
SSE <- sum(ehat^2)
F <- SSR / (k * sigmahat)
F

# p-value
pval <- 1 - pf(F, k, n - k - 1)
pval

# Coefficient of determination
SST <- SSR + SSE
R2 <- SSR / SST
R2
MSE <- SSE / (n - k - 1)
MST <- SST / (n - 1)
R2adj <- 1 - MSE / MST
R2adj

# Information criteria
AIC <- log(sum(ehat^2) / n) + 2 * (k + 1) / n
BIC <- log(sum(ehat^2) / n) + log(n) * (k + 1) / n
AIC
BIC

# In-sample predictions
Yhat <- X %*% bhat
Yhat

# 95% prediction intervals
se_p <- sqrt(sigmahat * diag(X %*% XXinv %*% t(X) + 1))
se_p
CI_p <- cbind(Yhat - se_p * t_critical, Yhat + se_p * t_critical)